#######################################################################
:mod:`.options.sonification <highcharts_core.options.sonification>`
#######################################################################

.. contents:: Module Contents
  :local:
  :depth: 3
  :backlinks: entry

.. toctree::
  :titlesonly:

  grouping
  mapping
  track_configurations

--------------

.. module:: highcharts_core.options.sonification

*******************************************************************************************************
class: :class:`SonificationOptions <highcharts_core.options.sonification.SonificationOptions>`
*******************************************************************************************************

.. autoclass:: SonificationOptions
  :members:
  :inherited-members:

-----------------------

***************************
Sub-components
***************************

.. list-table::
  :widths: 60 40
  :header-rows: 1

  * - Module
    - Classes / Functions
  * - :mod:`.options.sonification.grouping <highcharts_core.options.sonification.grouping>`
    - :class:`SonificationGrouping <highcharts_core.options.sonification.grouping.SonificationGrouping>`
  * - :mod:`.options.sonification.mapping <highcharts_core.options.sonification.mapping>`
    - :class:`SonificationMapping <highcharts_core.options.sonification.mapping.SonificationMapping>`
      :class:`AudioParameter <highcahrts_core.options.sonification.mapping.AudioParameter>`
      :class:`AudioFilter <highcharts_core.options.sonification.mapping.AudioFilter>`
      :class:`PitchParameter <highcharts_core.options.sonification.mapping.PitchParameter>`
      :class:`TremoloEffect <highcahrts_core.options.sonification.mapping.TremoloEffect>`
  * - :mod:`.options.sonification.track_configurations <highcharts_core.options.sonification.track_configurations>`
    - :class:`InstrumentTrackConfiguration <highcharts_core.options.sonification.track_configurations.InstrumentTrackConfiguration>`
      :class:`SpeechTrackConfiguration <highcharts_core.options.sonification.track_configurations.SpeechTrackConfiguration>`
      :class:`ContextTrackConfiguration <highcharts_core.options.sonification.track_configurations.ContextTrackConfiguration>`
      :class:`TrackConfigurationBase <highcharts_core.options.sonification.track_configurations.TrackConfigurationBase>`
      :class:`ActiveWhen <highcharts_core.options.sonification.track_configurations.ActiveWhen>`
